@@ -331,10 +331,21 @@ class GatewayApi(tornado.web.RequestHandler):
             self.set_status(response.status_code)
             self._headers = HTTPHeaders(response.headers)  # 注意：需要强制类型转换
 
+            if self._headers.get('Content-Type') == 'gzip':
+                try:
+                    self._headers.pop('Content-Type')
+                    self._headers.pop('Content-Length')
+                except:
+                    pass
+
             if self.request.headers.get('Origin'):
                 self.set_header('Access-Control-Allow-Credentials', 'true')
                 self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
 
+            if self._status_code in (204, 304) or 100 <= self._status_code < 200:
+                # 这些状态下response中不能有body，所以不应该write
+                return
+
             self.write(response.content)
         else:
             self.set_status(500)
@@ -372,6 +383,10 @@ class GatewayApi(tornado.web.RequestHandler):
                 self.set_header('Access-Control-Allow-Credentials', 'true')
                 self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
 
+            if self._status_code in (204, 304) or 100 <= self._status_code < 200:
+                # 这些状态下response中不能有body，所以不应该write
+                return
+
             self.write(response.content)
         else:
             self.set_status(500)
@@ -530,9 +545,6 @@ class WebSocketHub(tornado.websocket.WebSocketHandler):
     def check_origin(self, origin):
         return True
 
-    def allow_draft76(self):
-        return True
-
 
 class HealthChecker(tornado.web.RequestHandler):
     def get(self, *args, **kwargs):
